import numpy as np
import memray

def add_elems(elems):
    return np.unique(elems)

# Generate 100 million random 7-digit integers
random_integers = np.random.randint(low=1000000, high=10000000, size=100_000_000)

res = add_elems(random_integers)



import numpy as np
import pyperf

def add_elems(elems):
    return np.unique(elems)


# Generate 10 million random 7-digit integers
random_integers = np.random.randint(low=1000000, high=10000000, size=10_000_000)

runner = pyperf.Runner()
runner.bench_func(
    "10 million 7-digit random positive integers: numpy",
    add_elems, random_integers
)




import numpy as np
import pyperf
from count_distinct import CVM


def add_elems(counter, elems):
    for elem in elems:
        counter.add(elem)


# Generate 10 million random 7-digit integers
random_integers = np.random.randint(low=1000000, high=10000000, size=10_000_000)

counter = CVM(0.8, 0.1, 100000)

runner = pyperf.Runner()
runner.bench_func(
    "10 million 7-digit random positive integers",
    add_elems,
    counter,
    random_integers,
)
count = counter.calculate_final_result()
